# -*- coding: utf-8 -*-
#
#    Copyright 2019 Fabien Bourgeois <fabien@yaltik.com>
#    Copyright 2019 Youssef El Ouahby <youssef@yaltik.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

""" GOLEM Members Analysis Adaptation """

import logging
from odoo import models, fields, api, _
from odoo.exceptions import UserError, ValidationError
_LOGGER = logging.getLogger(__name__)


class GolemMemberAnalysis(models.TransientModel):
    """ GOLEM Members Analysis Adaptation """
    _inherit = 'golem.member.analysis.wizard'
    _description = 'GOLEM Members Analysis  Wizard Adaptation'

    analyse_type = fields.Selection([('age_start_gender', 'By age at season start and gender'),
                                     ('age_end_gender', 'By age at season end and gender'),
                                     ('age_start_area', 'By age at season start and area'),
                                     ('age_end_area', 'By age at season end and area'),
                                     ('age_start_tag', 'By age at season start and tag'),
                                     ('age_end_tag', 'By age at season end and tag'),
                                     ('fquotient__area', 'By family quotient and area')],
                                    required=True)

    @api.multi
    def get_pivot_view(self):
        """ override  get_pivot_view function """
        self.ensure_one()
        rec = self[0]
        pivot_view = super(GolemMemberAnalysis, self).get_pivot_view()
        if pivot_view:
            return pivot_view
        elif rec.analyse_type == 'fquotient__area':
            return self.env.ref(
                'golem_member_familyquotient.golem_member_analysis_pivot_fquotient_area', False)
